@@ -75,7 +75,7 @@ module SiSU_HTML_Scroll
         scr[:tails]=SiSU_HTML_Scroll::Scroll.new(@md).tails
         scr
       rescue
-        SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
+        SiSU_Errors::Rescued.new($!,$@,@md.opt.cmd,@md.fns).location do
           __LINE__.to_s + ':' + __FILE__
         end
       ensure
