@@ -161,7 +161,7 @@ module SiSU_Initialize
     end
     def trang_rnc_model_output_sax
       s=@suffix
-      rnc_src=@env.processing_path.dal + '/sax.' + s[:rnc]
+      rnc_src=@env.processing_path.ao + '/sax.' + s[:rnc]
       rnc_file=@path[:rnc] + '/' + @rxng.rnc_name.output_sax
       rng_file=@path[:rng] + '/' + @rxng.rng_name.output_sax
       xsd_file=@path[:xsd] + '/' + @rxng.xsd_name.output_sax
@@ -183,7 +183,7 @@ module SiSU_Initialize
     end
     def trang_rnc_model_output_dom
       s=@suffix
-      rnc_src=@env.processing_path.dal + '/dom.' + s[:rnc]
+      rnc_src=@env.processing_path.ao + '/dom.' + s[:rnc]
       rnc_file=@path[:rnc] + '/' + @rxng.rnc_name.output_dom
       rng_file=@path[:rng] + '/' + @rxng.rng_name.output_dom
       xsd_file=@path[:xsd] + '/' + @rxng.xsd_name.output_dom
@@ -205,7 +205,7 @@ module SiSU_Initialize
     end
     def trang_rnc_model_output_xhtml
       s=@suffix
-      rnc_src=@env.processing_path.dal + '/xhtml.' + s[:rnc]
+      rnc_src=@env.processing_path.ao + '/xhtml.' + s[:rnc]
       rnc_file=@path[:rnc] + '/' + @rxng.rnc_name.output_xhtml
       rng_file=@path[:rng] + '/' + @rxng.rng_name.output_xhtml
       xsd_file=@path[:xsd] + '/' + @rxng.xsd_name.output_xhtml
@@ -226,7 +226,7 @@ module SiSU_Initialize
       end
     end
     def trang_rnc_model_input_sax
-      rnc_file=@env.processing_path.dal + '/sax.rnc'
+      rnc_file=@env.processing_path.ao + '/sax.rnc'
       dtd_file=@path[:xsd] + '/' + @rxng.rng_name.input_sax
       rnc=File.new(rnc_file,'w')
       rnc << @rxng.rnc_model_output_sax
@@ -235,7 +235,7 @@ module SiSU_Initialize
       schema.relaxng(@opt.cmd)
     end
     def trang_rnc_model_input_dom
-      rnc_file=@env.processing_path.dal + '/dom.rnc'
+      rnc_file=@env.processing_path.ao + '/dom.rnc'
       dtd_file=@path[:xsd] + '/' + @rxng.rng_name.input_dom
       rnc=File.new(rnc_file,'w')
       rnc << @rxng.rnc_model_output_dom
@@ -244,7 +244,7 @@ module SiSU_Initialize
       schema.relaxng(@opt.cmd)
     end
     def trang_rnc_model_input_node
-      rnc_file=@env.processing_path.dal + '/node.rnc'
+      rnc_file=@env.processing_path.ao + '/node.rnc'
       dtd_file=@path[:xsd] + '/' + @rxng.rng_name.input_node
       rnc=File.new(rnc_file,'w')
       rnc << @rxng.rnc_model_input_node
