@@ -280,14 +280,14 @@ module SiSU
           Dir.chdir(@opt.pth) #watch
         end
         @env=SiSU_Env::InfoEnv.new(@opt.fns)
-        if @opt.act[:dal][:set]==:on                   #% --dal, -m
+        if @opt.act[:ao][:set]==:on                   #% --ao --dal, -m
           unless @opt.act[:po4a][:set]==:on            # --po4a, -P
             if @opt.fno =~ /\.ssm$/
               require_relative 'composite'             # composite.rb #pre-processing
               SiSU_Assemble::Composite.new(@opt).read
             end
-            require_relative 'dal'                     # -m     dal.rb
-            SiSU_DAL::Source.new(@opt).read
+            require_relative 'ao'                      # -m     ao.rb
+            SiSU_AO::Source.new(@opt).read
           end
         end
         if @opt.act[:qrcode][:set]==:on                #% --qrcode, -Q
@@ -299,8 +299,24 @@ module SiSU
           SiSU_DigestView::Source.new(@opt).read
         end
         if @opt.act[:txt][:set]==:on                   #% --txt, -t -a
-          require_relative 'plaintext'                 #  plaintext.rb
-          SiSU_Plaintext::Source.new(@opt).read
+          require_relative 'txt_plain'                 #  txt_plain.rb
+          SiSU_Txt_Plain::Source.new(@opt).read
+        end
+        if @opt.act[:txt_textile][:set]==:on           #% --textile
+          require_relative 'txt_textile'               #  txt_textile.rb
+          SiSU_Txt_Textile::Source.new(@opt).read
+        end
+        if @opt.act[:txt_asciidoc][:set]==:on          #% --asciidoc
+          require_relative 'txt_asciidoc'              #  txt_asciidoc.rb
+          SiSU_Txt_asciiDoc::Source.new(@opt).read
+        end
+        if @opt.act[:txt_markdown][:set]==:on          #% --markdown
+          require_relative 'txt_markdown'              #  txt_markdown.rb
+          SiSU_Txt_Markdown::Source.new(@opt).read
+        end
+        if @opt.act[:txt_rst][:set]==:on               #% --rst, --rest
+          require_relative 'txt_rst'                   #  txt_rst.rb
+          SiSU_Txt_rST::Source.new(@opt).read
         end
         if @opt.act[:html][:set]==:on                  #% --html, -h -H
           require_relative 'html'                      #  html.rb
@@ -320,12 +336,12 @@ module SiSU
           SiSU_Concordance::Source.new(@opt).read
         end
         if @opt.act[:epub][:set]==:on                  #% --epub, -e
-          require_relative 'epub'                      #  epub.rb
-          SiSU_EPUB::Source.new(@opt).read
+          require_relative 'xhtml_epub2'               # xhtml_epub2.rb
+          SiSU_XHTML_EPUB2::Source.new(@opt).read
         end
         if @opt.act[:odt][:set]==:on                   #% --odt, -o opendocument
-          require_relative 'odf'                       #  odf.rb
-          SiSU_ODF::Source.new(@opt).read
+          require_relative 'xml_odf_odt'               #  xml_odf_odt.rb
+          SiSU_XML_ODF_ODT::Source.new(@opt).read
         end
         if @opt.act[:xhtml][:set]==:on                 #% --xhtml, -b xhtml
           require_relative 'xhtml'                     #  xhtml.rb
@@ -339,8 +355,16 @@ module SiSU
           require_relative 'xml_scaffold_structure_collapsed' # xml_scaffold_structure_collapsed.rb
           SiSU_XML_Scaffold_Structure_Collapse::Source.new(@opt).read
         end
+        if @opt.act[:xml_docbook_book][:set]==:on      #% --xml-docbook
+          require_relative 'xml_docbook5'              # xml_docbook5.rb
+          SiSU_XML_Docbook_Book::Source.new(@opt).read
+        end
+        if @opt.act[:xml_fictionbook][:set]==:on       #% --xml-fictionbook
+          require_relative 'xml_fictionbook2'          # xml_fictionbook2.rb
+          SiSU_XML_Fictionbook::Source.new(@opt).read
+        end
         if @opt.act[:xml_sax][:set]==:on               #% --xml-sax, -x xml sax type
-          require_relative 'xml'                       #  xml.rb
+          require_relative 'xml_sax'                   #  xml_sax.rb
           SiSU_XML_SAX::Source.new(@opt).read
         end
         if @opt.act[:xml_dom][:set]==:on               #% --xml-dom, -X xml dom type
@@ -391,12 +415,12 @@ module SiSU
       or  @opt.act[:sisupod][:set]==:on \
       or  @opt.act[:git][:set]==:on
         begin
-          require_relative 'shared_sisupod_source'
+          require_relative 'src_shared'
           OptionLoopFiles.new(@opt).loop_files_on_given_option do
             SiSU_Source::SiSUpodSource.new(@opt).read
           end
           if @opt.act[:share_source][:set]==:on
-            require_relative 'share_src'               # -s     share_src.rb
+            require_relative 'src_share'               # -s     src_share.rb
             begin
             ensure
               OptionLoopFiles.new(@opt).loop_files_on_given_option_bundle do
@@ -405,7 +429,7 @@ module SiSU
             end
           end
           if @opt.act[:sisupod][:set]==:on             #% --sisupod, -S make sisupod
-            require_relative 'sisupod_make'            # -S     sisupod_make.rb
+            require_relative 'src_sisupod_make'        # -S     src_sisupod_make.rb
             begin
             ensure
               OptionLoopFiles.new(@opt).loop_files_on_given_option_bundle do
@@ -523,8 +547,13 @@ module SiSU
       SiSU_Env::InfoProcessingFlag.new
       if @opt.act[:version_info][:set]==:on            #% version information
         SiSU_Env::InfoAbout.new(@opt).sisu_version
+        if (@opt.act[:verbose][:set]==:on \
+        || @opt.act[:verbose_plus][:set]==:on \
+        || @opt.act[:maintenance][:set]==:on)
+          SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],' ' + File.dirname(__FILE__)).grey
+        end
       end
-      if @opt.act[:dal][:set]==:on \
+      if @opt.act[:ao][:set]==:on \
       or @opt.act[:maintenance][:set]==:on             #% --maintenance, -m for -C
         path={}
         path[:css]=@@env.path.output + '/_sisu/css'
@@ -576,7 +605,7 @@ module SiSU
       if @opt.act[:webrick][:set]==:on                 #% --webrick, -W webrick
         SiSU::Operations.new(@opt).webrick
       end
-      if @opt.act[:dal][:set]==:on
+      if @opt.act[:ao][:set]==:on
         @retry_count= -1
         begin
           @get_s,@get_p,@get_pl=[],[],[]
@@ -628,10 +657,14 @@ module SiSU
       and @opt.mod.join(';') =~/--(?:createdb|init(?:ialize)?|create(?:all)?|createtables|recreate|drop(?:all))/)
         :false
       else
-        (@opt.act[:dal][:set]==:on \
+        (@opt.act[:ao][:set]==:on \
         || @opt.act[:manpage][:set]==:on \
         || @opt.act[:texinfo][:set]==:on \
         || @opt.act[:txt][:set]==:on \
+        || @opt.act[:txt_textile][:set]==:on \
+        || @opt.act[:txt_asciidoc][:set]==:on \
+        || @opt.act[:txt_markdown][:set]==:on \
+        || @opt.act[:txt_rst][:set]==:on \
         || @opt.act[:html][:set]==:on \
         || @opt.act[:html_scroll][:set]==:on \
         || @opt.act[:html_seg][:set]==:on \
@@ -643,6 +676,8 @@ module SiSU
         || @opt.act[:xml_dom][:set]==:on \
         || @opt.act[:xml_scaffold_structure_sisu][:set]==:on \
         || @opt.act[:xml_scaffold_structure_collapse][:set]==:on \
+        || @opt.act[:xml_docbook_book][:set]==:on \
+        || @opt.act[:xml_fictionbook][:set]==:on \
         || @opt.act[:pdf][:set]==:on \
         || @opt.act[:pdf_p][:set]==:on \
         || @opt.act[:pdf_l][:set]==:on \
