@@ -61,7 +61,7 @@
 
 =end
 module SiSU_Po4a
-  require_relative 'dal'                                # dal.rb
+  require_relative 'ao'                                 # ao.rb
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
   require_relative 'composite'                          # composite.rb
@@ -101,7 +101,7 @@ module SiSU_Po4a
         end
         md=SiSU_Param::Parameters.new(@opt).get
         src[:files].each do |fn|
-          SiSU_DAL::Source.new(@opt,fn).read             # -m
+          SiSU_AO::Source.new(@opt,fn).read             # -m
           env=SiSU_Env::InfoEnv.new(@opt.fns)
           m=/((.+?)(?:\~\w\w(?:_\w\w)?)?)\.((?:-|ssm\.)?sst|ssm|ssi)$/ #watch added match for sss
           @fnn,@fnb,@fnt=fn[m,1],fn[m,2],fn[m,3]
@@ -126,7 +126,7 @@ module SiSU_Po4a
           if @opt.fns =~/\S+?~#{@lang_regx}\.ss[mti]/ \
           or @opt.f_pth[:lng] !=@opt.lng_base
             opt_lang_trn_fn=fn
-            @dal_array_lang_translation=SiSU_DAL::Source.new(@opt,opt_lang_trn_fn).get # dal file drawn here
+            @ao_array_lang_translation=SiSU_AO::Source.new(@opt,opt_lang_trn_fn).get # ao file drawn here
             opt_lang_src_fn=if fn =~/\S+?~\S{2}(?:_\S{2})?\.ss[mti]/
               fn.gsub(/(\S+?)~\S{2}(?:_\S{2})?(\.ss[mti])/,'\1\2') #check i
             else fn
@@ -141,15 +141,15 @@ module SiSU_Po4a
             else nil
             end
             if FileTest.file?("#{srcdir}/#{opt_lang_src_fn}")
-              @dal_array_lang_src=SiSU_DAL::Source.new(@@opt_src,opt_lang_src_fn).get # dal file drawn here
+              @ao_array_lang_src=SiSU_AO::Source.new(@@opt_src,opt_lang_src_fn).get # ao file drawn here
             else
               puts "no identified source document"
               exit
             end
             Dir.chdir(transdir) if transdir
           else
-            @dal_array_lang_src=SiSU_DAL::Source.new(@opt,fn).get # dal file drawn here
-            @dal_array_lang_translation=nil
+            @ao_array_lang_src=SiSU_AO::Source.new(@opt,fn).get # ao file drawn here
+            @ao_array_lang_translation=nil
           end
           wrap_width=if defined? md.make.plaintext_wrap \
           and md.make.plaintext_wrap
@@ -159,7 +159,7 @@ module SiSU_Po4a
             env.plaintext_wrap
           else 78
           end
-          SiSU_Po4a::Source::Scroll.new(fn,@dal_array_lang_src,@dal_array_lang_translation,@@md_src,@@md_trn,wrap_width).songsheet
+          SiSU_Po4a::Source::Scroll.new(fn,@ao_array_lang_src,@ao_array_lang_translation,@@md_src,@@md_trn,wrap_width).songsheet
         end
       rescue
         SiSU_Errors::Rescued.new($!,$@,@opt.cmd,@opt.fns).location do
