@@ -473,7 +473,7 @@ module SiSU_Translate
       'Document (RCS/CVS) number'
     end
     def last_generated
-      'Document (dal) last generated'
+      'Document (ao) last generated'
     end
     def sisu_version
       'Generated by'
@@ -1324,7 +1324,7 @@ module SiSU_Translate
       'Numero di revisione (RCS/CVS)'
     end
     def last_generated
-      'Data di ultima generazione (dal metaverse)'
+      'Data di ultima generazione (ao metaverse)'
     end
     def sisu_version
       'Generato da'
