@@ -72,35 +72,35 @@ module SiSU_Remote
       @remote=SiSU_Env::InfoRemote.new(opt)
     end
     def rsync
-      SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->',@put).dark_grey_title_hi unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement ->',@put).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.rsync.document
     end
     def rsync_base
-      SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->','rsync').dark_grey_title_hi unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement ->','rsync').dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.rsync.site_base
     end
     def rsync_base_sync
-      SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->','rsync and sync').dark_grey_title_hi unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement ->','rsync and sync').dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.rsync.site_base_sync
     end
     def rsync_sitemaps
-      SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement sitemaps ->','rsync').dark_grey_title_hi unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement sitemaps ->','rsync').dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.rsync_sitemaps
     end
     def rsync_harvest
-      SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement metadata harvest ->','rsync_harvest').dark_grey_title_hi unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement metadata harvest ->','rsync_harvest').dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.rsync.site_harvest
     end
     def scp
-      SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->',@put).dark_grey_title_hi unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement ->',@put).dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.scp.document
     end
     def scp_base
-      SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement of base site ->','excluding images').dark_grey_title_hi unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement of base site ->','excluding images').dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.scp.site_base
     end
     def scp_base_all
-      SiSU_Screen::Ansi.new(@opt.cmd,'Remote placement ->','complete').dark_grey_title_hi unless @opt.cmd =~/q/
+      SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],'Remote placement ->','complete').dark_grey_title_hi unless @opt.act[:quiet][:set]==:on
       @remote.scp.site_base_all
     end
   end
@@ -108,7 +108,7 @@ module SiSU_Remote
     def initialize(opt,get_s)
       @opt,@get_s=opt,get_s
       @msg,@msgs='',nil
-      @tell=lambda { SiSU_Screen::Ansi.new(@opt.cmd,@msg,"#{@msgs.inspect if @msgs}") }
+      @tell=lambda { SiSU_Screen::Ansi.new(@opt.act[:color_state][:set],@msg,"#{@msgs.inspect if @msgs}") }
     end
     def fns
       require 'open-uri'
@@ -141,12 +141,12 @@ module SiSU_Remote
               images.delete_if {|x| x =~/https?:\/\// }
               images=images.sort
               @msg,@msgs='downloading images:', [ images.join(',') ]
-              @tell.call.warn unless @opt.cmd =~/q/
+              @tell.call.warn unless @opt.act[:quiet][:set]==:on
               image_info=image_download_url + images
               SiSU_Assemble::RemoteImage.new.download_images(image_info)
               #SiSU_Assemble::RemoteImage.new.download_images(image_download_url,images)
               @msg,@msgs='downloading done',nil
-              @tell.call.warn unless @opt.cmd =~/q/
+              @tell.call.warn unless @opt.act[:quiet][:set]==:on
             end
             downloaded_file.close
           end
