@@ -64,7 +64,7 @@ module SiSU_Sitemaps
     include SiSU_Param
   require_relative 'sysenv'                             # sysenv.rb
     include SiSU_Env
-  require_relative 'shared_xml'                         # shared_xml.rb
+  require_relative 'xml_shared'                         # xml_shared.rb
     include SiSU_XML_Munge
   class Source
     def initialize(opt)
